# vizdxp

## Simple Data Visualization web application

vizdxp is an open-source web app designed via streamlit weaved with plotly library. **Its incredibly Simple - Just drag & drop any csv and explore the data visually.** By default the application will figure out better visualization based on user selections. Feel free to customize as needed.

## Keys
- **Simple** and quick for any **Exploratory data Analysis**
- Create interactive **Dashboard web app within minutes** from any csv and share the findings
- **Deploy** it as a web application in your own workstations too
- By **Default** - chart types and aggregations are applied based on columns selected by user, null rows are removed, date fields are converted to multiple subfields
- Highly **Customizable**
- No more static reports
- Chart types included in v0.0.4 - Scatter, Bar, Pie, Heatmap and Box plots

## Installation

- pip install vizdxp
- python -m vizdxp

Explore vizdxp through a browser. Once installation is complete, user can work totally offline.

**This package is also hosted [online](https://vizdxp.herokuapp.com) ** Pls feel free to explore with your own data


## Plans for Aug-Sep 2020
- Filtering Data
- Overall Performance improvement
- Possible Feature requests based on feedback raised in github

## License
- vizdxp is completely free and licensed under MIT license.
- Vizdxp is developed with Streamlit as the framework. Further details on [streamlit](https://www.streamlit.io/)
- Plotly is the visualization library used. Further details on [plotly](https://plotly.com/)